@@ -11,12 +11,12 @@
 #  define UNUSED
 #endif
 
-#endif /* __INCLUDED_DEBUG_H__ */
+#endif /* __INCLUDED_COMPILER_H__ */
 
 /* COPYRIGHT --
  *
  * This file is part of libhid, a user-space HID access library.
- * libhid is (c) 2003-2004
+ * libhid is (c) 2003-2005
  *   Martin F. Krafft <libhid@pobox.madduck.net>
  *   Charles Lepple <clepple@ghz.cc>
  *   Arnaud Quette <arnaud.quette@free.fr> && <arnaud.quette@mgeups.com>
